@@ -3,14 +3,14 @@ package Amazon::API::Botocore::Pod;
 use strict;
 use warnings;
 
-use parent qw{ Exporter };
+use parent qw( Exporter );
 
 use Pod::Usage;
 use Pod::Find qw(pod_where);
 
-our @EXPORT_OK = qw{ pod };
+our @EXPORT_OK = qw( pod );
 
-our $VERSION = '2.0.13'; ## no critic (RequireInterpolationOfMetachars)
+our $VERSION = '2.1.0';  ## no critic (RequireInterpolationOfMetachars)
 
 ########################################################################
 sub pod {
@@ -21,6 +21,7 @@ sub pod {
     -exitval => $exit_val,
     -input   => pod_where( { -inc => 1 }, __PACKAGE__ ),
     -output  => \*STDOUT,
+    -verbose => 1,
   );
 }
 
@@ -40,8 +41,8 @@ Amazon::API::Botocore - Automagic AWS API class generator
 
  amazon-api options command
 
- Options
- -------
+=head1 OPTIONS
+
  --botocore-path, -b  path to git botocore project, default: . or $BOTOCORE_PATH
  --help, -h           help
  --module-name, -m    module name suffix, Example: Route53 (see Notes below)
@@ -51,8 +52,8 @@ Amazon::API::Botocore - Automagic AWS API class generator
  --service, -s        Botocore API service, Example: route53
  --tidy, -t           perltidy output, default is true, use --no-tidy to disable
 
- Commands
- --------
+=head2 Commands
+
  describe           dump the Botocore metadata for a service
  create-stub(s)     create the Amazon::API::{service-name} from the Botocore
                     metadata
@@ -60,46 +61,54 @@ Amazon::API::Botocore - Automagic AWS API class generator
                     Botocore metadata
  help method|shape  show help for method or shape
 
- Notes
- -----
- 1. By default the API class created for a service will be named
-    Amazon::API::{service-name}. "service-name" will be derived from
-    the service option (-s) using the following rules:
+=head2 Notes
 
-    a. upper case all letters in service name if the length of the
-       name is 3 (i.e SNS, SQS, etc.)
-    b. upper case the first letter if the the length > 3
+=over 5
 
-    * if you don't like these rules, use the -m option to change the name ;-)
+=item 1. By default the API class created for a service will be named
+Amazon::API::{service-name}.
 
-2. The current working directory will be used as the root directory
-   for creating the API and shape classes. Use the -o option to create
-   the API in a different directory.s Directories will be created if
-   they do not exist.
+"service-name" will be derived from the service option (-s) using the following rules:
 
-3. Use this script to get help for specific APIs, methods
-   or shapes.
+=over 10
 
-   amazon-api -s sqs help
-   amazon-api -s sqs help CreateQueue
-   amazon-api -s sqs help CreateQueueRequest
+=item * upper case all letters in service name if the length of the name is 3 (i.e SNS, SQS, etc.)
 
-   Note that if you created a custom name for your API module
-   (example: SecretsManager), then use the API module short name for
-   the service.
+=item * upper case the first letter if the the length > 3
 
-   amazon-api -s SecretsManager help GetSecretValue
+=back
 
-4. Dump the entire Botocore description for an API
+If you don't like these rules, use the -m option to change the name ;-)
 
-   amazon-api -s sqs describe
+=item 2. The current working directory will be used as the root directory
+   for creating the API and shape classes.
 
-5. Don't like our pod?
+Use the -o option to create the API in a different directory.s Directories will be created if
+they do not exist.
 
-   amazon-api -s sqs describe | jq -r .sqs.operations.CreateQueue
+=item 3. Use this script to get help for specific APIs, methods or shapes.
+
+ amazon-api -s sqs help
+ amazon-api -s sqs help CreateQueue
+ amazon-api -s sqs help CreateQueueRequest
+
+I<Note that if you created a custom name for your API module (example:
+SecretsManager), then use the API module short name for the service.>
+
+ amazon-api -s SecretsManager help GetSecretValue
+
+=item 4. Dump the entire Botocore description for an API
+
+ amazon-api -s sqs describe
+
+=item 5. Don't like our pod?
+
+ amazon-api -s sqs describe | jq -r .sqs.operations.CreateQueue
 
 See also - perldoc Amazon::API::Botocore::Pod
 
+=back
+
 =head1 DESCRIPTION
 
 Generates Perl classes for Amazon APIs from Botocore specfications.
@@ -110,13 +119,14 @@ example:
 
  my $hosted_zone = $rt53->ListHostedZones;
 
- print Dumper([$hosted_zones]);
+ print Dumper([hosted_zones => $hosted_zones]);
 
 See L<Amazon::API> for more details.
 
 =head1 NOTES
 
-First build the project from either the GitHub repository or CPAN.
+First build the project from either the GitHub repository or by
+installing from CPAN with C<cpanm>.
 
 I<Note that building the project from the GitHub repository requires
 additional tooling you may not have in your environment. See
