@@ -6,11 +6,11 @@ use warnings;
 use parent qw(Exporter);
 
 use Amazon::API::Constants qw(:booleans :chars);
-use Amazon::API::Template  qw(:all);
+use Amazon::API::Template qw(:all);
 
 use Carp;
 use Data::Dumper;
-use English    qw(-no_match_vars);
+use English qw(-no_match_vars);
 use List::Util qw( pairs any );
 use ReadonlyX;
 use Scalar::Util qw(reftype blessed );
@@ -36,10 +36,9 @@ our @EXPORT_OK = qw(
 
 our %EXPORT_TAGS = ( all => [@EXPORT_OK] );
 
-Readonly::Scalar our $SHAPE_NAME_TEMPLATE =>
-  'Amazon::API::Botocore::Shape::%s::%s';
+Readonly::Scalar our $SHAPE_NAME_TEMPLATE => 'Amazon::API::Botocore::Shape::%s::%s';
 
-our $VERSION = '2.0.13'; ## no critic (RequireInterpolationOfMetachars)
+our $VERSION = '2.1.0';  ## no critic (RequireInterpolationOfMetachars)
 
 our $TEMPLATE_START = tell DATA;
 
@@ -70,7 +69,7 @@ sub create_module_name {
   my ($service) = @_;
 
   return uc $service
-    if length $service == 3; # SQS SNS IAM STS SES RDS...
+    if length $service == 3;  # SQS SNS IAM STS SES RDS...
 
   # just return name if mix of upper/lower, else upper case first letter
   return $service =~ /[[:upper:]]/xsm ? $service : ucfirst $service;
@@ -129,7 +128,7 @@ sub snake_case {
 ########################################################################
   my ($name) = @_;
 
-  while ( $name =~ s/([[:upper:]])([[:lower:]])/lc("_$1").$2/xsme ) { }; # snake_case the CamelCase
+  while ( $name =~ s/([[:upper:]])([[:lower:]])/lc("_$1").$2/xsme ) { };  # snake_case the CamelCase
 
   $name =~ s/^_//xsm;
 
@@ -271,7 +270,7 @@ sub param_n {
 ########################################################################
   my ( $message, $prefix, $idx ) = @_;
 
-  if ( !defined $idx ) { # first call, check args
+  if ( !defined $idx ) {  # first call, check args
     croak 'message argument must be reference'
       if !ref $message;
   }
@@ -281,15 +280,13 @@ sub param_n {
   if ( ref $message ) {
     if ( reftype($message) eq 'HASH' ) {
       foreach my $k ( keys %{$message} ) {
-        push @param_n,
-          param_n( $message->{$k}, $prefix ? "$prefix.$k" : $k, $idx );
+        push @param_n, param_n( $message->{$k}, $prefix ? "$prefix.$k" : $k, $idx );
       }
     } ## end if ( reftype($message)...)
     else {
       $idx = 1;
       foreach my $e ( @{$message} ) {
-        push @param_n,
-          param_n( $e, $prefix ? "$prefix.$idx" : $EMPTY, $idx++ );
+        push @param_n, param_n( $e, $prefix ? "$prefix.$idx" : $EMPTY, $idx++ );
       }
     } ## end else [ if ( reftype($message)...)]
   } ## end if ( ref $message )
@@ -316,8 +313,7 @@ sub create_shape {
 ########################################################################
   my (%args) = @_;
 
-  my ( $shape_name, $service_description, $service )
-    = @args{qw( name service_description service )};
+  my ( $shape_name, $service_description, $service ) = @args{qw( name service_description service )};
 
   my $shapes = $service_description->{shapes};
 
@@ -346,9 +342,7 @@ sub create_shape {
       my $type          = $member->{shape};
       my $location_name = $member->{locationName} || $m;
 
-      $type = sprintf 'L<%s|Amazon::API::Botocore::Shape::%s::%s/%s>', $type,
-        $service,
-        $type, $type;
+      $type = sprintf 'L<%s|Amazon::API::Botocore::Shape::%s::%s/%s>', $type, $service, $type, $type;
 
       push @see_also, $type;
 
@@ -356,22 +350,18 @@ sub create_shape {
       $description =~ s/\A\n+//xsm;
       $description =~ s/[\n]+\z//xsm;
 
-      my $item = <<'END_OF_ITEM';
-=item Name: %s
-
-=over 10
-
-=item Type
-
-%s
-
-=item Description
-
-%s
-
-=back
-END_OF_ITEM
+      my @item_block = (
+        '=item'    => 'Name: %s',
+        '=over 10' => $EMPTY,
+        '=item'    => "Type\n\n%s",
+        '=item'    => "Description\n\n%s",
+        '=back'    => $EMPTY,
+      );
 
+      my $item = $EMPTY;
+      foreach my $p ( pairs @item_block ) {
+        $item .= join $SPACE, @{$p}, "\n";
+      }
       push @members, sprintf $item, $m, $type, $description;
     }
   }
